(function (Drupal, drupalSettings) {
    Drupal.behaviors.smartFaqChatbot = {
      attach: function (context, settings) {
        const container = document.querySelector('#smart-faq-chatbot');
        if (!container || container.dataset.attached) {
          return;
        }
        container.dataset.attached = 'true';
  
        const input = document.getElementById('chatbot-user-input');
        const sendBtn = document.getElementById('chatbot-send-btn');
        const messagesDiv = document.getElementById('chatbot-messages');
  
        function appendMessage(content, type = 'user') {
          const message = document.createElement('div');
          message.className = 'chatbot-message ' + type;
          message.textContent = content;
          messagesDiv.appendChild(message);
          messagesDiv.scrollTop = messagesDiv.scrollHeight;
        }
  
        async function sendMessage() {
          const userInput = input.value.trim();
          if (!userInput) return;
  
          appendMessage(userInput, 'user');
          input.value = '';
          sendBtn.disabled = true;
  
          appendMessage('Thinking...', 'bot');
  
          // Get selected values
          const contentType = document.getElementById('chatbot-content-type')?.value || '';
          const taxonomyTerm = document.getElementById('chatbot-taxonomy-term')?.value || '';
          const productType = document.getElementById('chatbot-product-type')?.value || '';
       
          try {
            const response = await fetch('/smart-faq-chatbot/ask', {
              method: 'POST',
              headers: {
                'Content-Type': 'application/json',
                'X-CSRF-Token': drupalSettings.csrfToken || document.querySelector('meta[name="csrf-token"]').getAttribute('content'),
              },
              body: JSON.stringify({ question: userInput,
                content_type: contentType,
                taxonomy_term: taxonomyTerm,
                product_type: productType }),
            });
  
            const data = await response.json();
            const lastBotMessage = messagesDiv.querySelector('.chatbot-message.bot:last-child');
            if (lastBotMessage) {
              lastBotMessage.remove();
            }
  
            appendMessage(data.answer || 'Sorry, no response.', 'bot');
          } catch (error) {
            appendMessage('Error contacting the chatbot service.', 'bot');
          } finally {
            sendBtn.disabled = false;
          }
        }
  
        sendBtn.addEventListener('click', sendMessage);
        input.addEventListener('keydown', function (e) {
          if (e.key === 'Enter') {
            sendMessage();
          }
        });
        // Dropdown toggle logic for menu blocks
        const toggleButtons = document.querySelectorAll('.menu-toggle');
        toggleButtons.forEach(button => {
            button.addEventListener('click', function () {
            const menuBlock = this.closest('.menu-block');
            if (menuBlock) {
                menuBlock.classList.toggle('active');
            }
            });
        });
        
      },
    };
  })(Drupal, drupalSettings);
  