<?php

namespace Drupal\smart_faq_chatbot\Controller;

use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\smart_faq_chatbot\Service\SmartChatbotService;

/**
 * Controller for handling chatbot interaction.
 */
class SmartChatbotController extends ControllerBase {

  protected SmartChatbotService $chatbotService;

  public function __construct(SmartChatbotService $chatbotService) {
    $this->chatbotService = $chatbotService;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('smart_faq_chatbot.service')
    );
  }

  public function ask(Request $request): JsonResponse {
    $data = json_decode($request->getContent(), TRUE);
    $question = $data['question'] ?? '';
    $contentType = $data['content_type'] ?? '';
    $taxonomyTerm = $data['taxonomy_term'] ?? '';
    $productType = $data['product_type'] ?? '';
    if (empty($question)) {
      return new JsonResponse(['error' => 'No question provided.'], 400);
    }

    $answer = $this->chatbotService->getAnswer($question, $contentType, $taxonomyTerm, $productType);
    return new JsonResponse(['answer' => $answer]);
  }

}
