<?php

namespace Drupal\smart_faq_chatbot\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines a settings form for the Smart FAQ Chatbot.
 */
class SmartChatbotSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'smart_chatbot_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['smart_faq_chatbot.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('smart_faq_chatbot.settings');

    $form['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Gemini API Key'),
      '#default_value' => $config->get('api_key'),
      '#description' => $this->t('Enter your Gemini API key to enable chatbot functionality.'),
      '#required' => TRUE,
    ];

    $form['system_prompt'] = [
      '#type' => 'textarea',
      '#title' => $this->t('System Prompt'),
      '#default_value' => $config->get('system_prompt') ?: 'You are a helpful assistant for answering frequently asked questions based on Drupal site content.',
      '#description' => $this->t('Define the behavior and tone of the chatbot. This will be prepended to each user query.'),
      '#rows' => 5,
    ];

    $form['max_tokens'] = [
      '#type' => 'number',
      '#title' => $this->t('Max Tokens'),
      '#default_value' => $config->get('max_tokens') ?? 500,
      '#description' => $this->t('Maximum number of tokens in the chatbot response.'),
      '#min' => 100,
      '#max' => 4096,
    ];
    $form['site_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Site Name'),
      '#default_value' => $config->get('site_name'),
      '#description' => $this->t('Give a short name or title for this site.'),
    ];
    
    $form['site_description'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Site Description'),
      '#default_value' => $config->get('site_description'),
      '#description' => $this->t('Briefly describe what this site is about, its goals, and its audience.'),
      '#rows' => 3,
    ];
    
    $form['site_features'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Site Features'),
      '#default_value' => $config->get('site_features'),
      '#description' => $this->t('List key features or technologies used (e.g., search, geolocation, custom content types).'),
      '#rows' => 3,
    ];
    
    $form['site_keywords'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Site Keywords'),
      '#default_value' => $config->get('site_keywords'),
      '#description' => $this->t('Comma-separated list of tags that describe this site’s purpose or content.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->configFactory->getEditable('smart_faq_chatbot.settings')
      ->set('api_key', $form_state->getValue('api_key'))
      ->set('system_prompt', $form_state->getValue('system_prompt'))
      ->set('max_tokens', $form_state->getValue('max_tokens'))
      ->set('site_name', $form_state->getValue('site_name'))
      ->set('site_description', $form_state->getValue('site_description'))
      ->set('site_features', $form_state->getValue('site_features'))
      ->set('site_keywords', $form_state->getValue('site_keywords'))
      ->save();

    parent::submitForm($form, $form_state);
    $this->messenger()->addMessage($this->t('Smart FAQ Chatbot settings have been saved.'));
  }

}
